# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from .x_hatch_window_controller import XHatchWindowController as XHatchWindowController_45430fe1

class XHatchWindow(XComponent_98dc0ab5):
    """
    specifies the operations for a hatch window.
    
    A hatch window is a kind of window that is adopted to contain an embedded object window to represent the contained window border and to handle resizing/moving in a specific way: after user have selected the new size/placement the hatching window sends request to owner for resizing/moving. Thus the window can not resize/move itself.

    See Also:
        `API XHatchWindow <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XHatchWindow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XHatchWindow'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XHatchWindow'

    @abstractmethod
    def setController(self, xController: XHatchWindowController_45430fe1) -> None:
        """
        sets the object that will control resizing/moving, if the object is not set the window can not be resized/moved.
        """
        ...
    @abstractproperty
    def HatchBorderSize(self) -> Size_576707ef:
        """
        """
        ...


__all__ = ['XHatchWindow']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text


class BibliographyDataField(object):
    """
    Const Class

    These values define parts of bibliographic data.
    
    They are used to create a bibliography in a text document.
    
    Depending on the type of the data some of the fields will usually be left empty.
    
    **since**
    
        LibreOffice 7.3

    See Also:
        `API BibliographyDataField <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.BibliographyDataField'
    __ooo_type_name__: str = 'const'

    IDENTIFIER = 0
    """
    This field contains a unique identifier for the bibliographic data.
    """
    BIBILIOGRAPHIC_TYPE = 1
    """
    This field contains the type of the bibliographic reference.
    
    It is of the type BibliographyDataType.
    """
    ADDRESS = 2
    """
    This field contains the address of the publisher.
    """
    ANNOTE = 3
    """
    This field contains an annotation.
    """
    AUTHOR = 4
    """
    This field contains the name(s) of the author(s)
    """
    BOOKTITLE = 5
    """
    This field contains the title of the book.
    """
    CHAPTER = 6
    """
    This field contains the name or number of the chapter.
    """
    EDITION = 7
    """
    This field contains the number or name of the edition.
    """
    EDITOR = 8
    """
    This field contains the name(s) of the editor(s)
    """
    HOWPUBLISHED = 9
    """
    This field contains a description of the type of the publishing.
    """
    INSTITUTION = 10
    """
    This field contains the name of the institution where the publishing was created.
    """
    JOURNAL = 11
    """
    This field contains the name of the journal.
    """
    MONTH = 12
    """
    This field contains number or name of the month of the publishing.
    """
    NOTE = 13
    """
    This field contains a note.
    """
    NUMBER = 14
    """
    This field contains the number of the publishing.
    """
    ORGANIZATIONS = 15
    """
    This field contains the name of the organizations where the publishing was created.
    """
    PAGES = 16
    """
    This field contains the number(s) of the page(s) of the reference into a publishing.
    """
    PUBLISHER = 17
    """
    This field contains the name of the publisher.
    """
    SCHOOL = 18
    """
    This field contains the name of the university or school where the publishing was created.
    """
    SERIES = 19
    """
    This field contains the series of the publishing.
    """
    TITLE = 20
    """
    This field contains the title of the publishing.
    """
    REPORT_TYPE = 21
    """
    This field contains a description of the type of the report.
    """
    VOLUME = 22
    """
    This field contains the volume of the publishing.
    """
    YEAR = 23
    """
    This field contains the year when the publishing was created.
    """
    URL = 24
    """
    This field contains URL of the publishing.
    """
    CUSTOM1 = 25
    """
    This field contains user defined data.
    """
    CUSTOM2 = 26
    """
    This field contains user defined data.
    """
    CUSTOM3 = 27
    """
    This field contains user defined data.
    """
    CUSTOM4 = 28
    """
    This field contains user defined data.
    """
    CUSTOM5 = 29
    """
    This field contains user defined data.
    """
    ISBN = 30
    """
    This field contains the ISBN data of the publishing.
    """
    LOCAL_URL = 31
    """
    This field contains a local copy of the publishing.
    
    **since**
    
        LibreOffice 7.3
    """

__all__ = ['BibliographyDataField']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CalendarDisplayCode(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.CalendarDisplayCode", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.CalendarDisplayCode``"""
        pass

    class CalendarDisplayCodeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.CalendarDisplayCode", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.CalendarDisplayCode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import CalendarDisplayCode as CalendarDisplayCode
    else:
        # keep document generators happy
        from ...lo.i18n.calendar_display_code import CalendarDisplayCode as CalendarDisplayCode

    class CalendarDisplayCodeEnum(IntEnum):
        """
        Enum of Const Class CalendarDisplayCode

        Constants to use with XExtendedCalendar.getDisplayString().
        
        The examples given are for an English Gregorian calendar, note that other calendars or locales may return completely different strings, for example not a four digit year but a CJK name instead.
        
        **since**
        
            OOo 1.1.2
        """
        SHORT_DAY = CalendarDisplayCode.SHORT_DAY
        """
        Day of month, one or two digits, no leading zero.
        """
        LONG_DAY = CalendarDisplayCode.LONG_DAY
        """
        Day of month, two digits, with leading zero.
        """
        SHORT_DAY_NAME = CalendarDisplayCode.SHORT_DAY_NAME
        """
        Day of week, abbreviated name.
        """
        LONG_DAY_NAME = CalendarDisplayCode.LONG_DAY_NAME
        """
        Day of week, full name.
        """
        SHORT_MONTH = CalendarDisplayCode.SHORT_MONTH
        """
        Month of year, one or two digits, no leading zero.
        """
        LONG_MONTH = CalendarDisplayCode.LONG_MONTH
        """
        Month of year, with leading zero.
        """
        SHORT_MONTH_NAME = CalendarDisplayCode.SHORT_MONTH_NAME
        """
        Abbreviated month name.
        """
        LONG_MONTH_NAME = CalendarDisplayCode.LONG_MONTH_NAME
        """
        Full month name.
        """
        SHORT_YEAR = CalendarDisplayCode.SHORT_YEAR
        """
        Year, two digits.
        """
        LONG_YEAR = CalendarDisplayCode.LONG_YEAR
        """
        Year, four digits.
        """
        SHORT_ERA = CalendarDisplayCode.SHORT_ERA
        """
        Abbreviated era name, for example, BC or AD.
        """
        LONG_ERA = CalendarDisplayCode.LONG_ERA
        """
        Full era name, for example, \"Before Christ\" or \"Anno Dominus\".
        """
        SHORT_YEAR_AND_ERA = CalendarDisplayCode.SHORT_YEAR_AND_ERA
        """
        Combined short year and era, order depends on locale/calendar.
        """
        LONG_YEAR_AND_ERA = CalendarDisplayCode.LONG_YEAR_AND_ERA
        """
        Combined full year and era, order depends on locale/calendar.
        """
        SHORT_QUARTER = CalendarDisplayCode.SHORT_QUARTER
        """
        Short quarter, for example, \"Q1\".
        """
        LONG_QUARTER = CalendarDisplayCode.LONG_QUARTER
        """
        Long quarter, for example, \"1st quarter\".
        """
        SHORT_GENITIVE_MONTH_NAME = CalendarDisplayCode.SHORT_GENITIVE_MONTH_NAME
        """
        Abbreviated possessive genitive case month name.
        
        **since**
        
            LibreOffice 3.5
        """
        LONG_GENITIVE_MONTH_NAME = CalendarDisplayCode.LONG_GENITIVE_MONTH_NAME
        """
        Full possessive genitive case month name.
        
        **since**
        
            LibreOffice 3.5
        """
        NARROW_GENITIVE_MONTH_NAME = CalendarDisplayCode.NARROW_GENITIVE_MONTH_NAME
        """
        Narrow possessive genitive case month name.
        
        **since**
        
            LibreOffice 3.5
        """
        SHORT_PARTITIVE_MONTH_NAME = CalendarDisplayCode.SHORT_PARTITIVE_MONTH_NAME
        """
        Abbreviated partitive case month name.
        
        **since**
        
            LibreOffice 3.5
        """
        LONG_PARTITIVE_MONTH_NAME = CalendarDisplayCode.LONG_PARTITIVE_MONTH_NAME
        """
        Full partitive case month name.
        
        **since**
        
            LibreOffice 3.5
        """
        NARROW_PARTITIVE_MONTH_NAME = CalendarDisplayCode.NARROW_PARTITIVE_MONTH_NAME
        """
        Narrow partitive case month name.
        
        **since**
        
            LibreOffice 3.5
        """
        NARROW_DAY_NAME = CalendarDisplayCode.NARROW_DAY_NAME
        """
        Day of week, narrow name.
        
        **since**
        
            LibreOffice 3.5
        """
        NARROW_MONTH_NAME = CalendarDisplayCode.NARROW_MONTH_NAME
        """
        Narrow month name.
        
        **since**
        
            LibreOffice 3.5
        """

__all__ = ['CalendarDisplayCode', 'CalendarDisplayCodeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08

class DataPilotItem(XPropertySet_bc180bfa, XNamed_a6520b08):
    """
    Service Class

    represents a single item in a data pilot field.
    
    **since**
    
        OOo 2.4

    See Also:
        `API DataPilotItem <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotItem'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsHidden(self) -> bool:
        """
        specifies whether the item is hidden.
        """
        ...

    @abstractproperty
    def Position(self) -> int:
        """
        specifies the item's position in its field if sorting is manual.
        
        **since**
        
            OOo 2.4
        """
        ...

    @abstractproperty
    def ShowDetail(self) -> bool:
        """
        specifies whether the item is showing detail.
        """
        ...


__all__ = ['DataPilotItem']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.sdb.boolean_comparison_mode import BooleanComparisonMode as BooleanComparisonMode
from ...lo.sdb.callable_statement import CallableStatement as CallableStatement
from ...lo.sdb.column import Column as Column
from ...lo.sdb.column_descriptor_control import ColumnDescriptorControl as ColumnDescriptorControl
from ...lo.sdb.column_descriptor_control_model import ColumnDescriptorControlModel as ColumnDescriptorControlModel
from ...lo.sdb.column_settings import ColumnSettings as ColumnSettings
from ...lo.sdb.command_definition import CommandDefinition as CommandDefinition
from ...lo.sdb.command_type import CommandType as CommandType
from ...lo.sdb.connection import Connection as Connection
from ...lo.sdb.content_loader import ContentLoader as ContentLoader
from ...lo.sdb.data_access_descriptor import DataAccessDescriptor as DataAccessDescriptor
from ...lo.sdb.data_access_descriptor_factory import DataAccessDescriptorFactory as DataAccessDescriptorFactory
from ...lo.sdb.data_column import DataColumn as DataColumn
from ...lo.sdb.data_settings import DataSettings as DataSettings
from ...lo.sdb.data_source import DataSource as DataSource
from ...lo.sdb.data_source_browser import DataSourceBrowser as DataSourceBrowser
from ...lo.sdb.database_access import DatabaseAccess as DatabaseAccess
from ...lo.sdb.database_access_connection import DatabaseAccessConnection as DatabaseAccessConnection
from ...lo.sdb.database_access_context import DatabaseAccessContext as DatabaseAccessContext
from ...lo.sdb.database_access_data_source import DatabaseAccessDataSource as DatabaseAccessDataSource
from ...lo.sdb.database_context import DatabaseContext as DatabaseContext
from ...lo.sdb.database_document import DatabaseDocument as DatabaseDocument
from ...lo.sdb.database_environment import DatabaseEnvironment as DatabaseEnvironment
from ...lo.sdb.database_interaction_handler import DatabaseInteractionHandler as DatabaseInteractionHandler
from ...lo.sdb.database_registration_event import DatabaseRegistrationEvent as DatabaseRegistrationEvent
from ...lo.sdb.datasource_administration_dialog import DatasourceAdministrationDialog as DatasourceAdministrationDialog
from ...lo.sdb.definition_container import DefinitionContainer as DefinitionContainer
from ...lo.sdb.definition_content import DefinitionContent as DefinitionContent
from ...lo.sdb.document import Document as Document
from ...lo.sdb.document_container import DocumentContainer as DocumentContainer
from ...lo.sdb.document_data_source import DocumentDataSource as DocumentDataSource
from ...lo.sdb.document_definition import DocumentDefinition as DocumentDefinition
from ...lo.sdb.document_save_request import DocumentSaveRequest as DocumentSaveRequest
from ...lo.sdb.error_condition import ErrorCondition as ErrorCondition
from ...lo.sdb.error_message_dialog import ErrorMessageDialog as ErrorMessageDialog
from ...lo.sdb.filter_dialog import FilterDialog as FilterDialog
from ...lo.sdb.forms import Forms as Forms
from ...lo.sdb.interaction_handler import InteractionHandler as InteractionHandler
from ...lo.sdb.office_database_document import OfficeDatabaseDocument as OfficeDatabaseDocument
from ...lo.sdb.order_column import OrderColumn as OrderColumn
from ...lo.sdb.order_dialog import OrderDialog as OrderDialog
from ...lo.sdb.parameters_request import ParametersRequest as ParametersRequest
from ...lo.sdb.prepared_statement import PreparedStatement as PreparedStatement
from ...lo.sdb.query import Query as Query
from ...lo.sdb.query_definition import QueryDefinition as QueryDefinition
from ...lo.sdb.query_descriptor import QueryDescriptor as QueryDescriptor
from ...lo.sdb.query_design import QueryDesign as QueryDesign
from ...lo.sdb.relation_design import RelationDesign as RelationDesign
from ...lo.sdb.report_design import ReportDesign as ReportDesign
from ...lo.sdb.reports import Reports as Reports
from ...lo.sdb.result_column import ResultColumn as ResultColumn
from ...lo.sdb.result_set import ResultSet as ResultSet
from ...lo.sdb.row_change_action import RowChangeAction as RowChangeAction
from ...lo.sdb.row_change_event import RowChangeEvent as RowChangeEvent
from ...lo.sdb.row_set import RowSet as RowSet
from ...lo.sdb.row_set_veto_exception import RowSetVetoException as RowSetVetoException
from ...lo.sdb.rows_change_event import RowsChangeEvent as RowsChangeEvent
from ...lo.sdb.sql_context import SQLContext as SQLContext
from ...lo.sdb.sql_error_event import SQLErrorEvent as SQLErrorEvent
from ...lo.sdb.sql_filter_operator import SQLFilterOperator as SQLFilterOperator
from ...lo.sdb.sql_query_composer import SQLQueryComposer as SQLQueryComposer
from ...lo.sdb.single_select_query_analyzer import SingleSelectQueryAnalyzer as SingleSelectQueryAnalyzer
from ...lo.sdb.single_select_query_composer import SingleSelectQueryComposer as SingleSelectQueryComposer
from ...lo.sdb.table import Table as Table
from ...lo.sdb.table_definition import TableDefinition as TableDefinition
from ...lo.sdb.table_descriptor import TableDescriptor as TableDescriptor
from ...lo.sdb.table_design import TableDesign as TableDesign
from ...lo.sdb.text_connection_settings import TextConnectionSettings as TextConnectionSettings
from ...lo.sdb.x_alter_query import XAlterQuery as XAlterQuery
from ...lo.sdb.x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier
from ...lo.sdb.x_column import XColumn as XColumn
from ...lo.sdb.x_column_update import XColumnUpdate as XColumnUpdate
from ...lo.sdb.x_command_preparation import XCommandPreparation as XCommandPreparation
from ...lo.sdb.x_completed_connection import XCompletedConnection as XCompletedConnection
from ...lo.sdb.x_completed_execution import XCompletedExecution as XCompletedExecution
from ...lo.sdb.x_data_access_descriptor_factory import XDataAccessDescriptorFactory as XDataAccessDescriptorFactory
from ...lo.sdb.x_database_access import XDatabaseAccess as XDatabaseAccess
from ...lo.sdb.x_database_access_listener import XDatabaseAccessListener as XDatabaseAccessListener
from ...lo.sdb.x_database_context import XDatabaseContext as XDatabaseContext
from ...lo.sdb.x_database_environment import XDatabaseEnvironment as XDatabaseEnvironment
from ...lo.sdb.x_database_registrations import XDatabaseRegistrations as XDatabaseRegistrations
from ...lo.sdb.x_database_registrations_listener import XDatabaseRegistrationsListener as XDatabaseRegistrationsListener
from ...lo.sdb.x_document_data_source import XDocumentDataSource as XDocumentDataSource
from ...lo.sdb.x_form_documents_supplier import XFormDocumentsSupplier as XFormDocumentsSupplier
from ...lo.sdb.x_interaction_document_save import XInteractionDocumentSave as XInteractionDocumentSave
from ...lo.sdb.x_interaction_supply_parameters import XInteractionSupplyParameters as XInteractionSupplyParameters
from ...lo.sdb.x_office_database_document import XOfficeDatabaseDocument as XOfficeDatabaseDocument
from ...lo.sdb.x_parameters_supplier import XParametersSupplier as XParametersSupplier
from ...lo.sdb.x_queries_supplier import XQueriesSupplier as XQueriesSupplier
from ...lo.sdb.x_query_definition import XQueryDefinition as XQueryDefinition
from ...lo.sdb.x_query_definitions_supplier import XQueryDefinitionsSupplier as XQueryDefinitionsSupplier
from ...lo.sdb.x_report_documents_supplier import XReportDocumentsSupplier as XReportDocumentsSupplier
from ...lo.sdb.x_result_set_access import XResultSetAccess as XResultSetAccess
from ...lo.sdb.x_row_set_approve_broadcaster import XRowSetApproveBroadcaster as XRowSetApproveBroadcaster
from ...lo.sdb.x_row_set_approve_listener import XRowSetApproveListener as XRowSetApproveListener
from ...lo.sdb.x_row_set_change_broadcaster import XRowSetChangeBroadcaster as XRowSetChangeBroadcaster
from ...lo.sdb.x_row_set_change_listener import XRowSetChangeListener as XRowSetChangeListener
from ...lo.sdb.x_row_set_supplier import XRowSetSupplier as XRowSetSupplier
from ...lo.sdb.x_rows_change_broadcaster import XRowsChangeBroadcaster as XRowsChangeBroadcaster
from ...lo.sdb.x_rows_change_listener import XRowsChangeListener as XRowsChangeListener
from ...lo.sdb.xsql_error_broadcaster import XSQLErrorBroadcaster as XSQLErrorBroadcaster
from ...lo.sdb.xsql_error_listener import XSQLErrorListener as XSQLErrorListener
from ...lo.sdb.xsql_query_composer import XSQLQueryComposer as XSQLQueryComposer
from ...lo.sdb.xsql_query_composer_factory import XSQLQueryComposerFactory as XSQLQueryComposerFactory
from ...lo.sdb.x_single_select_query_analyzer import XSingleSelectQueryAnalyzer as XSingleSelectQueryAnalyzer
from ...lo.sdb.x_single_select_query_composer import XSingleSelectQueryComposer as XSingleSelectQueryComposer
from ...lo.sdb.x_sub_document import XSubDocument as XSubDocument
from ...lo.sdb.x_text_connection_settings import XTextConnectionSettings as XTextConnectionSettings



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_connection import XConnection as XConnection_a36a0b0c
from .x_warnings_supplier import XWarningsSupplier as XWarningsSupplier_ef210d99

class Connection(XComponent_98dc0ab5, XConnection_a36a0b0c, XWarningsSupplier_ef210d99):
    """
    Service Class

    represents a connection (session) with a specific database.
    
    Within the context of a Connection, SQL statements are executed and results are returned.
    
    A Connection's database is able to provide information describing its tables, its supported SQL grammar, its stored procedures, and the capabilities of this connection. This information is obtained with the com.sun.star.sdbc.XConnection.getMetaData() method.
    
    Note:  By default the Connection automatically commits changes after executing each statement. If auto commit has been disabled, an explicit commit must be done or database changes will not be saved.

    See Also:
        `API Connection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1Connection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.Connection'
    __ooo_type_name__: str = 'service'


__all__ = ['Connection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class LineStyle(Enum):
    """
    Enum Class


    See Also:
        `API LineStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7>`_
    """
    __ooo_ns__: str = "com.sun.star.drawing"
    __ooo_full_ns__: str = "com.sun.star.drawing.LineStyle"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.drawing.LineStyle"

    DASH = "DASH"
    """
    the line use dashes.
    """
    NONE = "NONE"
    """
    the area is not filled.
    
    The text size is only defined by the font properties.
    
    Don't animate this text.
    
    the line is hidden.
    
    the joint between lines will not be connected
    
    the line has no special end.
    """
    SOLID = "SOLID"
    """
    use a solid color to fill the area.
    
    the line is solid.
    """

__all__ = ["LineStyle"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .color import Color as Color_68e908c5
    from .x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class XNumberFormatter(XInterface_8f010a43):
    """
    represents a number formatter.

    See Also:
        `API XNumberFormatter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XNumberFormatter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XNumberFormatter'

    @abstractmethod
    def attachNumberFormatsSupplier(self, xSupplier: XNumberFormatsSupplier_3afb0fb7) -> None:
        """
        attaches an XNumberFormatsSupplier to this NumberFormatter.
        
        This NumberFormatter will only use the NumberFormats specified in the attached XNumberFormatsSupplier. Without an attached XNumberFormatsSupplier, no formatting is possible.
        """
        ...
    @abstractmethod
    def convertNumberToString(self, nKey: int, fValue: float) -> str:
        """
        converts a number into a string.
        """
        ...
    @abstractmethod
    def convertStringToNumber(self, nKey: int, aString: str) -> float:
        """
        converts a string which contains a formatted number into a number.
        
        If this is a text format, the string will not be converted.

        Raises:
            com.sun.star.util.NotNumericException: ``NotNumericException``
        """
        ...
    @abstractmethod
    def detectNumberFormat(self, nKey: int, aString: str) -> int:
        """
        detects the number format in a string which contains a formatted number.

        Raises:
            com.sun.star.util.NotNumericException: ``NotNumericException``
        """
        ...
    @abstractmethod
    def formatString(self, nKey: int, aString: str) -> str:
        """
        converts a string into another string.
        """
        ...
    @abstractmethod
    def getInputString(self, nKey: int, fValue: float) -> str:
        """
        converts a number into a string with the specified format.
        
        This string can always be converted back to a number using the same format.
        """
        ...
    @abstractmethod
    def getNumberFormatsSupplier(self) -> XNumberFormatsSupplier_3afb0fb7:
        """
        """
        ...
    @abstractmethod
    def queryColorForNumber(self, nKey: int, fValue: float, aDefaultColor: Color_68e908c5) -> Color_68e908c5:
        """
        """
        ...
    @abstractmethod
    def queryColorForString(self, nKey: int, aString: str, aDefaultColor: Color_68e908c5) -> Color_68e908c5:
        """
        """
        ...

__all__ = ['XNumberFormatter']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
from __future__ import annotations
from abc import abstractproperty
from .x_animate import XAnimate as XAnimate_ca680c52

class XAnimateMotion(XAnimate_ca680c52):
    """
    Interface for animation by defining motion on a path.

    See Also:
        `API XAnimateMotion <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimateMotion.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.XAnimateMotion'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.animations.XAnimateMotion'

    @abstractproperty
    def Origin(self) -> object:
        """
        Specifies the origin of motion for the animation.
        
        The values and semantics of this attribute are dependent upon the used animation engine.
        """
        ...

    @abstractproperty
    def Path(self) -> object:
        """
        Specifies an optional path.
        
        If a path is used, the From, To and By members are ignored. The value type of the path depends on the used rendering system. Possible types maybe a svg:d path encoded in a string.
        """
        ...


__all__ = ['XAnimateMotion']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .rectangle import Rectangle as Rectangle_84b109e9

class XRegion(XInterface_8f010a43):
    """
    manages multiple rectangles which make up a region.

    See Also:
        `API XRegion <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XRegion.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XRegion'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XRegion'

    @abstractmethod
    def clear(self) -> None:
        """
        makes this region an empty region.
        """
        ...
    @abstractmethod
    def excludeRectangle(self, Rect: Rectangle_84b109e9) -> None:
        """
        removes the area of the specified rectangle from this region.
        """
        ...
    @abstractmethod
    def excludeRegion(self, Region: XRegion) -> None:
        """
        removes the area of the specified region from this region.
        """
        ...
    @abstractmethod
    def getBounds(self) -> Rectangle_84b109e9:
        """
        returns the bounding box of the shape.
        """
        ...
    @abstractmethod
    def getRectangles(self) -> typing.Tuple[Rectangle_84b109e9, ...]:
        """
        returns all rectangles which are making up this region.
        """
        ...
    @abstractmethod
    def intersectRectangle(self, Region: Rectangle_84b109e9) -> None:
        """
        intersects the specified rectangle with the current region.
        """
        ...
    @abstractmethod
    def intersectRegion(self, Region: XRegion) -> None:
        """
        intersects the specified region with the current region.
        """
        ...
    @abstractmethod
    def move(self, nHorzMove: int, nVertMove: int) -> None:
        """
        moves this region by the specified horizontal and vertical delta.
        """
        ...
    @abstractmethod
    def unionRectangle(self, Rect: Rectangle_84b109e9) -> None:
        """
        adds the specified rectangle to this region.
        """
        ...
    @abstractmethod
    def unionRegion(self, Region: XRegion) -> None:
        """
        adds the specified region to this region.
        """
        ...
    @abstractmethod
    def xOrRectangle(self, Rect: Rectangle_84b109e9) -> None:
        """
        applies an exclusive-or operation with the specified rectangle to this region.
        """
        ...
    @abstractmethod
    def xOrRegion(self, Region: XRegion) -> None:
        """
        applies an exclusive-or operation with the specified region to this region.
        """
        ...

__all__ = ['XRegion']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XInputStream(XInterface_8f010a43):
    """
    This is the basic interface to read data from a stream.
    
    See the streaming document for further information on chaining and piping streams.

    See Also:
        `API XInputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XInputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XInputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XInputStream'

    @abstractmethod
    def available(self) -> int:
        """
        states how many bytes can be read or skipped without blocking.
        
        Note: This method offers no information on whether the EOF has been reached.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def closeInput(self) -> None:
        """
        closes the stream.
        
        Users must close the stream explicitly when no further reading should be done. (There may exist ring references to chained objects that can only be released during this call. Thus not calling this method would result in a leak of memory or external resources.)

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readBytes(self, aData: uno.ByteSequence, nBytesToRead: int) -> int:
        """
        reads the specified number of bytes in the given sequence.
        
        The return value specifies the number of bytes which have been put into the sequence. A difference between nBytesToRead and the return value indicates that EOF has been reached. This means that the method blocks until the specified number of bytes are available or the EOF is reached.

        * ``aData`` is an out direction argument.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.BufferSizeExceededException: ``BufferSizeExceededException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readSomeBytes(self, aData: uno.ByteSequence, nMaxBytesToRead: int) -> int:
        """
        reads the available number of bytes, at maximum nMaxBytesToRead.
        
        This method is very similar to the readBytes method, except that it has different blocking behaviour. The method blocks as long as at least 1 byte is available or EOF has been reached. EOF has only been reached, when the method returns 0 and the corresponding byte sequence is empty. Otherwise, after the call, aData contains the available, but no more than nMaxBytesToRead, bytes.

        * ``aData`` is an out direction argument.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.BufferSizeExceededException: ``BufferSizeExceededException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def skipBytes(self, nBytesToSkip: int) -> None:
        """
        skips the next nBytesToSkip bytes (must be positive).
        
        It is up to the implementation whether this method is blocking the thread or not.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.BufferSizeExceededException: ``BufferSizeExceededException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XInputStream']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.registry.cannot_register_implementation_exception import CannotRegisterImplementationException as CannotRegisterImplementationException
with suppress(ImportError):
    from ...dyn.registry.default_registry import DefaultRegistry as DefaultRegistry
with suppress(ImportError):
    from ...dyn.registry.implementation_registration import ImplementationRegistration as ImplementationRegistration
with suppress(ImportError):
    from ...dyn.registry.invalid_registry_exception import InvalidRegistryException as InvalidRegistryException
with suppress(ImportError):
    from ...dyn.registry.invalid_value_exception import InvalidValueException as InvalidValueException
with suppress(ImportError):
    from ...dyn.registry.merge_conflict_exception import MergeConflictException as MergeConflictException
with suppress(ImportError):
    from ...dyn.registry.nested_registry import NestedRegistry as NestedRegistry
with suppress(ImportError):
    from ...dyn.registry.registry_key_type import RegistryKeyType as RegistryKeyType
with suppress(ImportError):
    from ...dyn.registry.registry_value_type import RegistryValueType as RegistryValueType
with suppress(ImportError):
    from ...dyn.registry.simple_registry import SimpleRegistry as SimpleRegistry
with suppress(ImportError):
    from ...dyn.registry.x_implementation_registration import XImplementationRegistration as XImplementationRegistration
with suppress(ImportError):
    from ...dyn.registry.x_implementation_registration2 import XImplementationRegistration2 as XImplementationRegistration2
with suppress(ImportError):
    from ...dyn.registry.x_registry_key import XRegistryKey as XRegistryKey
with suppress(ImportError):
    from ...dyn.registry.x_simple_registry import XSimpleRegistry as XSimpleRegistry



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_dispatch import XDispatch as XDispatch_98ff0a9b
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_dispatch_result_listener import XDispatchResultListener as XDispatchResultListener_582b1060
    from ..util.url import URL as URL_57ad07b9

class XNotifyingDispatch(XDispatch_98ff0a9b):
    """
    dispatch with guaranteed notify (instead of XDispatch)

    See Also:
        `API XNotifyingDispatch <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XNotifyingDispatch.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XNotifyingDispatch'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XNotifyingDispatch'

    @abstractmethod
    def dispatchWithNotification(self, URL: URL_57ad07b9, Arguments: typing.Tuple[PropertyValue_c9610c73, ...], Listener: XDispatchResultListener_582b1060) -> None:
        """
        Do the same like XDispatch.dispatch() but notifies listener in every case.
        
        Should be used if result must be known.
        """
        ...

__all__ = ['XNotifyingDispatch']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class AccessibleRole(metaclass=UnoConstMeta, type_name="com.sun.star.accessibility.AccessibleRole", name_space="com.sun.star.accessibility"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.accessibility.AccessibleRole``"""
        pass

    class AccessibleRoleEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.accessibility.AccessibleRole", name_space="com.sun.star.accessibility"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.accessibility.AccessibleRole`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.accessibility import AccessibleRole as AccessibleRole
    else:
        # keep document generators happy
        from ...lo.accessibility.accessible_role import AccessibleRole as AccessibleRole

    class AccessibleRoleEnum(IntEnum):
        """
        Enum of Const Class AccessibleRole

        Collection of roles.
        
        This collection of constants defines the set of possible roles of classes implementing the XAccessible interface according to the Java class javax.accessibility.AccessibleRole. The role of an object describes its generic function like \"button\", \"menu\", or \"text\". You can obtain an object's role by calling the getAccessibleRole() method of the XAccessibleContext interface.
        
        We are using constants instead of a more typesafe enum. The reason for this is that IDL enums may not be extended. Therefore, in order to include future extensions to the set of roles we have to use constants here.
        
        For some roles there exist two labels with the same value. Please use the one with the underscores. The other ones are somewhat deprecated and will be removed in the future.
        
        **since**
        
            OOo 1.1.2
        """
        UNKNOWN = AccessibleRole.UNKNOWN
        """
        Unknown role.
        
        The object contains some Accessible information, but its role is not known.
        """
        ALERT = AccessibleRole.ALERT
        """
        Object is used to alert the user about something.
        """
        COLUMN_HEADER = AccessibleRole.COLUMN_HEADER
        """
        The header for a column of data.
        """
        CANVAS = AccessibleRole.CANVAS
        """
        Object that can be drawn into and is used to trap events.
        
        See also FRAME, GLASS_PANE, and LAYERED_PANE.
        """
        CHECK_BOX = AccessibleRole.CHECK_BOX
        """
        Check box role.
        
        A choice that can be checked or unchecked and provides a separate indicator for the current state.
        
        See also PUSH_BUTTON, TOGGLE_BUTTON, and RADIO_BUTTON.
        """
        CHECK_MENU_ITEM = AccessibleRole.CHECK_MENU_ITEM
        """
        This role is used for check buttons that are menu items.
        """
        COLOR_CHOOSER = AccessibleRole.COLOR_CHOOSER
        """
        A specialized dialog that lets the user choose a color.
        """
        COMBO_BOX = AccessibleRole.COMBO_BOX
        """
        Combo box role.
        
        A list of choices the user can select from. Also optionally allows the user to enter a choice of their own.
        """
        DATE_EDITOR = AccessibleRole.DATE_EDITOR
        """
        Date editor role.
        
        A DATE_EDITOR is a component that allows users to edit date and time.
        """
        DESKTOP_ICON = AccessibleRole.DESKTOP_ICON
        """
        An iconified internal frame in a DESKTOP_PANE.
        
        See also DESKTOP_PANE and INTERNAL_FRAME.
        """
        DESKTOP_PANE = AccessibleRole.DESKTOP_PANE
        """
        Desktop pane role.
        
        A pane that supports internal frames and iconified versions of those internal frames.
        """
        DIRECTORY_PANE = AccessibleRole.DIRECTORY_PANE
        """
        Directory pane role.
        
        A pane that allows the user to navigate through and select the contents of a directory. May be used by a file chooser.
        
        See also FILE_CHOOSER.
        """
        DIALOG = AccessibleRole.DIALOG
        """
        Dialog box role.
        
        A top level window with title bar and a border. A dialog is similar to a frame, but it has fewer properties and is often used as a secondary window for an application.
        
        See also FRAME and WINDOW.
        """
        DOCUMENT = AccessibleRole.DOCUMENT
        """
        View of a document.
        
        The view of an actual document. Its content depends on the document type.
        """
        EMBEDDED_OBJECT = AccessibleRole.EMBEDDED_OBJECT
        """
        Embedded (OLE) object.
        """
        END_NOTE = AccessibleRole.END_NOTE
        """
        Text that is used as an endnote (footnote at the end of a chapter or section.
        """
        FILE_CHOOSER = AccessibleRole.FILE_CHOOSER
        """
        File chooser role.
        
        A specialized dialog that displays the files in the directory and lets the user select a file, browse a different directory, or specify a filename. May use the directory pane to show the contents of a directory.
        
        See also DIRECTORY_PANE.
        """
        FILLER = AccessibleRole.FILLER
        """
        Filler role.
        
        An object that fills up space in a user interface. It is often used in interfaces to tweak the spacing between components, but serves no other purpose.
        """
        FONT_CHOOSER = AccessibleRole.FONT_CHOOSER
        """
        Font chooser role.
        
        A FONT_CHOOSER is a component that lets the user pick various attributes for fonts.
        """
        FOOTER = AccessibleRole.FOOTER
        """
        Footer of a document page.
        """
        FOOTNOTE = AccessibleRole.FOOTNOTE
        """
        Text that is used as a footnote.
        """
        FRAME = AccessibleRole.FRAME
        """
        Frame role.
        
        A top level window with a title bar, border, menu bar, etc. It is often used as the primary window for an application.
        
        See also DIALOG, CANVAS, and WINDOW.
        """
        GLASS_PANE = AccessibleRole.GLASS_PANE
        """
        Glass pane role.
        
        A pane that is guaranteed to be painted on top of all panes beneath it.
        
        See also ROOT_PANE and CANVAS.
        """
        GRAPHIC = AccessibleRole.GRAPHIC
        """
        Graphical object.
        """
        GROUP_BOX = AccessibleRole.GROUP_BOX
        """
        Group box role.
        
        A GROUP_BOX is a simple container that contains a border around it and contains components inside it.
        """
        HEADER = AccessibleRole.HEADER
        """
        Header of a document page.
        """
        HEADING = AccessibleRole.HEADING
        """
        Chapter or section heading.
        """
        HYPER_LINK = AccessibleRole.HYPER_LINK
        """
        A hypertext anchor.
        """
        ICON = AccessibleRole.ICON
        """
        A small fixed size picture, typically used to decorate components.
        """
        INTERNAL_FRAME = AccessibleRole.INTERNAL_FRAME
        """
        Internal frame role.
        
        A frame-like object that is clipped by a desktop pane. The desktop pane, internal frame, and desktop icon objects are often used to create multiple document interfaces within an application.
        
        See also DESKTOP_ICON, DESKTOP_PANE, and FRAME.
        """
        LABEL = AccessibleRole.LABEL
        """
        An object used to present an icon or short string in an interface.
        
        See also TEXT and STATIC.
        """
        LAYERED_PANE = AccessibleRole.LAYERED_PANE
        """
        layered pane role.
        
        A specialized pane that allows its children to be drawn in layers, providing a form of stacking order. This is usually the pane that holds the menu bar as well as the pane that contains most of the visual components in a window.
        
        See also GLASS_PANE and ROOT_PANE.
        """
        LIST = AccessibleRole.LIST
        """
        List role.
        
        An object that presents a list of objects to the user and allows the user to select one or more of them. A list is usually contained within a scroll pane.
        
        See also SCROLL_PANE and LIST_ITEM.
        """
        LIST_ITEM = AccessibleRole.LIST_ITEM
        """
        List item role.
        
        An object that presents an element in a list. A list is usually contained within a scroll pane.
        
        See also SCROLL_PANE and LIST.
        """
        MENU = AccessibleRole.MENU
        """
        Menu role.
        
        An object usually found inside a menu bar that contains a list of actions the user can choose from. A menu can have any object as its children, but most often they are menu items, other menus, or rudimentary objects such as radio buttons, check boxes, or separators. For example, an application may have an \"Edit\" menu that contains menu items for \"Cut\" and \"Paste.\"
        
        See also MENU_BAR, MENU_ITEM, SEPARATOR, RADIO_BUTTON, CHECK_BOX, and POPUP_MENU.
        """
        MENU_BAR = AccessibleRole.MENU_BAR
        """
        Menu bar role.
        
        An object usually drawn at the top of the primary dialog box of an application that contains a list of menus the user can choose from. For example, a menu bar might contain menus for \"File,\" \"Edit,\" and \"Help.\"
        
        See also MENU, POPUP_MENU, and LAYERED_PANE.
        """
        MENU_ITEM = AccessibleRole.MENU_ITEM
        """
        Menu item role.
        
        An object usually contained in a menu that presents an action the user can choose. For example, the \"Cut\" menu item in an \"Edit\" menu would be an action the user can select to cut the selected area of text in a document.
        
        See also MENUBAR, SEPARATOR, and POPUP_MENU.
        """
        OPTION_PANE = AccessibleRole.OPTION_PANE
        """
        A specialized pane whose primary use is inside a DIALOG.
        
        See also DIALOG.
        """
        PAGE_TAB = AccessibleRole.PAGE_TAB
        """
        Page tab role.
        
        An object that is a child of a page tab list. Its sole child is the panel that is to be presented to the user when the user selects the page tab from the list of tabs in the page tab list.
        
        See also PAGE_TAB_LIST.
        """
        PAGE_TAB_LIST = AccessibleRole.PAGE_TAB_LIST
        """
        Page tab list role.
        
        An object that presents a series of panels (or page tabs), one at a time, through some mechanism provided by the object. The most common mechanism is a list of tabs at the top of the panel. The children of a page tab list are all page tabs.
        
        See also PAGE_TAB.
        """
        PANEL = AccessibleRole.PANEL
        """
        A generic container that is often used to group objects.
        """
        PARAGRAPH = AccessibleRole.PARAGRAPH
        """
        Paragraph of text.
        """
        PASSWORD_TEXT = AccessibleRole.PASSWORD_TEXT
        """
        Password text role.
        
        A text object used for passwords, or other places where the text contents is not shown visibly to the user.
        """
        POPUP_MENU = AccessibleRole.POPUP_MENU
        """
        Pop-up menu role.
        
        A temporary window that is usually used to offer the user a list of choices, and then hides when the user selects one of those choices.
        
        See also MENU and MENU_ITEM.
        """
        PUSH_BUTTON = AccessibleRole.PUSH_BUTTON
        """
        Push button role.
        
        An object the user can manipulate to tell the application to do something.
        
        See also CHECK_BOX, TOGGLE_BUTTON, RADIO_BUTTON, BUTTON_MENU and BUTTON_DROPDOWN.
        """
        PROGRESS_BAR = AccessibleRole.PROGRESS_BAR
        """
        An object used to indicate how much of a task has been completed.
        """
        RADIO_BUTTON = AccessibleRole.RADIO_BUTTON
        """
        Radio button role.
        
        A specialized check box that will cause other radio buttons in the same group to become unchecked when this one is checked.
        
        See also PUSH_BUTTON, TOGGLE_BUTTON, and CHECK_BOX.
        """
        RADIO_MENU_ITEM = AccessibleRole.RADIO_MENU_ITEM
        """
        This role is used for radio buttons that are menu items.
        """
        ROW_HEADER = AccessibleRole.ROW_HEADER
        """
        The header for a row of data.
        """
        ROOT_PANE = AccessibleRole.ROOT_PANE
        """
        Root pane role.
        
        A specialized pane that has a glass pane and a layered pane as its children.
        
        See also GLASS_PANE and LAYERED_PANE.
        """
        SCROLL_BAR = AccessibleRole.SCROLL_BAR
        """
        Scroll bar role.
        
        An object usually used to allow a user to incrementally view a large amount of data. Usually used only by a scroll pane.
        
        See also SCROLL_PANE.
        """
        SCROLL_PANE = AccessibleRole.SCROLL_PANE
        """
        Scroll pane role.
        
        An object that allows a user to incrementally view a large amount of information. Its children can include scroll bars and a viewport.
        
        See also SCROLL_BAR and VIEW_PORT.
        """
        SHAPE = AccessibleRole.SHAPE
        """
        Object with graphical representation used to represent content on draw pages.
        """
        SEPARATOR = AccessibleRole.SEPARATOR
        """
        Separator role.
        
        An object usually contained in a menu to provide a visual and logical separation of the contents in a menu. For example, the \"File\" menu of an application might contain menu items for \"Open,\" \"Close,\" and \"Exit,\" and will place a separator between \"Close\" and \"Exit\" menu items.
        
        See also MENU and MENU_ITEM.
        """
        SLIDER = AccessibleRole.SLIDER
        """
        Slider role.
        
        An object that allows the user to select from a bounded range. For example, a slider might be used to select a number between 0 and 100.
        """
        SPIN_BOX = AccessibleRole.SPIN_BOX
        """
        Spin box role.
        
        A SPIN_BOX is a simple spinner component and its main use is for simple numbers.
        """
        SPLIT_PANE = AccessibleRole.SPLIT_PANE
        """
        Split pane role.
        
        A specialized panel that presents two other panels at the same time. Between the two panels is a divider the user can manipulate to make one panel larger and the other panel smaller.
        """
        STATUS_BAR = AccessibleRole.STATUS_BAR
        """
        Status bar role.
        
        A STATUS_BAR is an simple component that can contain multiple labels of status information to the user.
        """
        TABLE = AccessibleRole.TABLE
        """
        Table component.
        
        An object used to present information in terms of rows and columns. An example might include a spreadsheet application.
        """
        TABLE_CELL = AccessibleRole.TABLE_CELL
        """
        Single cell in a table.
        """
        TEXT = AccessibleRole.TEXT
        """
        Text role.
        
        An object that presents text to the user. The text is usually editable by the user as opposed to a label or static text.
        
        See also LABEL and STATIC.
        """
        TEXT_FRAME = AccessibleRole.TEXT_FRAME
        """
        Collection of objects that constitute a logical text entity.
        """
        TOGGLE_BUTTON = AccessibleRole.TOGGLE_BUTTON
        """
        Toggle button role.
        
        A specialized push button that can be checked or unchecked, but does not provide a separate indicator for the current state.
        
        See also PUSH_BUTTON, CHECK_BOX and RADIO_BUTTON.
        """
        TOOL_BAR = AccessibleRole.TOOL_BAR
        """
        Tool bar role.
        
        A bar or palette usually composed of push buttons or toggle buttons. It is often used to provide the most frequently used functions for an application.
        """
        TOOL_TIP = AccessibleRole.TOOL_TIP
        """
        Tool tip role.
        
        An object that provides information about another object. The accessible Description property of the tool tip is often displayed to the user in a small \"help bubble\" when the user causes the mouse to hover over the object associated with the tool tip.
        """
        TREE = AccessibleRole.TREE
        """
        Tree role.
        
        An object used to present hierarchical information to the user. The individual nodes in the tree can be collapsed and expanded to provide selective disclosure of the tree's contents.
        """
        VIEW_PORT = AccessibleRole.VIEW_PORT
        """
        Viewport role.
        
        An object usually used in a scroll pane. It represents the portion of the entire data that the user can see. As the user manipulates the scroll bars, the contents of the viewport can change.
        
        See also SCROLL_PANE.
        """
        WINDOW = AccessibleRole.WINDOW
        """
        A top level window with no title or border.
        
        See also FRAME and DIALOG.
        """
        BUTTON_DROPDOWN = AccessibleRole.BUTTON_DROPDOWN
        """
        Button dropdown role.
        
        The object represents a button that drops down a list of items.
        
        See also PUSH_BUTTON and BUTTON_MENU.
        
        **since**
        
            OOo 3.0
        """
        BUTTON_MENU = AccessibleRole.BUTTON_MENU
        """
        Button menu role.
        
        The object represents a button that drops down a menu.
        
        See also PUSH_BUTTON and BUTTON_DROPDOWN.
        
        **since**
        
            OOo 3.0
        """
        CAPTION = AccessibleRole.CAPTION
        """
        Caption role.
        
        The object contains descriptive information, usually textual, about another user interface element such as a table, chart, or image.
        
        .
        
        **since**
        
            OOo 3.0
        """
        CHART = AccessibleRole.CHART
        """
        Chart role.
        
        The object is a graphical depiction of quantitative data. It may contain multiple subelements whose attributes and/or description may be queried to obtain both the quantitative data and information about how the data is being presented.
        
        **since**
        
            OOo 3.0
        """
        EDIT_BAR = AccessibleRole.EDIT_BAR
        """
        Edit bar role.
        
        A role indicating the object acts as a formula for calculating a value.
        
        **since**
        
            OOo 3.0
        """
        FORM = AccessibleRole.FORM
        """
        Form role.
        
        The object is a container for form controls, for instance as part of a web form or user-input form within a document.
        
        **since**
        
            OOo 3.0
        """
        IMAGE_MAP = AccessibleRole.IMAGE_MAP
        """
        Image map role.
        
        Usually a graphic with multiple hotspots, where each hotspot can be activated resulting in the loading of another document or section of a document.
        
        **since**
        
            OOo 3.0
        """
        NOTE = AccessibleRole.NOTE
        """
        Note role.
        
        An embedded note which is not visible until activated.
        
        **since**
        
            OOo 3.0
        """
        PAGE = AccessibleRole.PAGE
        """
        Page role.
        
        An object representing a page of document content. It is used in documents which are accessed by the user on a page by page basis.
        
        **since**
        
            OOo 3.0
        """
        RULER = AccessibleRole.RULER
        """
        Ruler role.
        
        An object which describes margins and tab stops, etc. for text objects which it controls.
        
        **since**
        
            OOo 3.0
        """
        SECTION = AccessibleRole.SECTION
        """
        Section role.
        
        The object is a containing instance of document content which constitutes a particular \"logical\" section of the document.
        
        **since**
        
            OOo 3.0
        """
        TREE_ITEM = AccessibleRole.TREE_ITEM
        """
        Tree item role.
        
        An object that presents an element in a tree
        
        See also TREE and TREE_TABLE.
        
        **since**
        
            OOo 3.0
        """
        TREE_TABLE = AccessibleRole.TREE_TABLE
        """
        Tree table role.
        
        An object which represents both hierarchical and tabular information.
        
        **since**
        
            OOo 3.0
        """
        COMMENT = AccessibleRole.COMMENT
        """
        Comment role.
        
        An object which represents a comment.
        
        A comment is anchored at a certain content position in the document and annotates this document content position or a certain text range of the document content. In the OpenDocument file format a comment is known as an annotation.
        
        See also COMMENT_END.
        
        **since**
        
            OOo 3.2
        """
        COMMENT_END = AccessibleRole.COMMENT_END
        """
        Comment end role.
        
        An invisible object which represents the end position of a text range which is annotated by a comment - see COMMENT.
        
        This object and the corresponding object representing the comment shall be in relation of type MEMBER_OF.
        
        **since**
        
            OOo 3.2
        """
        DOCUMENT_PRESENTATION = AccessibleRole.DOCUMENT_PRESENTATION
        """
        View of a presentation document.
        
        It's an specific variation of DOCUMENT for presentations.
        
        **since**
        
            LibreOffice 4.3
        """
        DOCUMENT_SPREADSHEET = AccessibleRole.DOCUMENT_SPREADSHEET
        """
        View of an spreadsheet document.
        
        It's an specific variation of DOCUMENT for spreadsheets.
        
        **since**
        
            LibreOffice 4.3
        """
        DOCUMENT_TEXT = AccessibleRole.DOCUMENT_TEXT
        """
        View of a text document.
        
        It's an specific variation of DOCUMENT for text.
        
        **since**
        
            LibreOffice 4.3
        """
        STATIC = AccessibleRole.STATIC
        """
        Static text role.
        
        An object that presents a brief amount of information to the user. The text is not editable by the user as opposed to a text, and not meant to have a relation with another object as opposed to a label.
        
        See also LABEL and TEXT.
        """

__all__ = ['AccessibleRole', 'AccessibleRoleEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class FormulaLanguage(object):
    """
    Const Class

    Constants designating the formula language used with XFormulaOpCodeMapper methods.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API FormulaLanguage <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FormulaLanguage'
    __ooo_type_name__: str = 'const'

    ODFF = 0
    """
    Function names and operators as defined by the OASIS OpenDocument Format (ODF) Formula specification (ODFF aka OpenFormula).
    """
    ODF_11 = 1
    """
    Function names and operators as used in ODF documents prior to the ODFF specification, up to ODF v1.1.
    """
    ENGLISH = 2
    """
    Function names and operators as used in the English language user interface.
    """
    NATIVE = 3
    """
    Function names and operators as used in the current native language user interface.
    """
    XL_ENGLISH = 4
    """
    Function names and operators as used in the English version of Excel.
    
    This formula language is also used in VBA formulas.
    """
    OOXML = 5
    """
    Function names and operators as used in OOXML.
    
    **since**
    
        LibreOffice 4.2
    """
    API = 6
    """
    Function names and operators as used with XFunctionAccess and other API context.
    
    Names are mostly identical to ENGLISH and ODF_11, but while ENGLISH names can be adapted to UI needs and ODF_11 has to stay error compatible, the API names strive to stay compatible but may get corrected in case of errors. Earlier versions than LibreOffice 5.3 always used ODF_11 in API context.
    
    **since**
    
        LibreOffice 5.3
    """

__all__ = ['FormulaLanguage']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a

class XStreamListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events from an active data control.

    See Also:
        `API XStreamListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XStreamListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XStreamListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XStreamListener'

    @abstractmethod
    def closed(self) -> None:
        """
        gets called when data transfer terminates normally or when data transfer is terminated from outside.
        
        The termination could be done using the method XActiveDataControl.terminate().
        """
        ...
    @abstractmethod
    def error(self, aException: object) -> None:
        """
        gets called when an internal error in source or sink has occurred.
        
        After the method is called, the close is called on the connected streams.
        """
        ...
    @abstractmethod
    def started(self) -> None:
        """
        gets called as soon as data transfer has started.
        """
        ...
    @abstractmethod
    def terminated(self) -> None:
        """
        gets called when XActiveDataControl.terminate() is called.
        """
        ...

__all__ = ['XStreamListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .drop_target_drag_event import DropTargetDragEvent as DropTargetDragEvent_d60612e7
from ...uno.x_interface import XInterface as XInterface_8f010a43
from .x_drop_target_drag_context import XDropTargetDragContext as XDropTargetDragContext_10221422
import typing
from ..data_flavor import DataFlavor as DataFlavor_ffd30deb


class DropTargetDragEnterEvent(DropTargetDragEvent_d60612e7):
    """
    Struct Class

    The DropTargetDragEnterEvent is delivered from the drop target to the currently registered drop target listeners whenever the logical cursor associated with a Drag and Drop operation enters the visible geometry of a window associated with a drop target.
    
    It contains the com.sun.star.datatransfer.DataFlavor types supported by the transferable object of the current Drag and Drop operation.

    See Also:
        `API DropTargetDragEnterEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DropTargetDragEnterEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.DropTargetDragEnterEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.datatransfer.dnd.DropTargetDragEnterEvent'
    """Literal Constant ``com.sun.star.datatransfer.dnd.DropTargetDragEnterEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Dummy: typing.Optional[int] = 0, Context: typing.Optional[XDropTargetDragContext_10221422] = None, DropAction: typing.Optional[int] = 0, LocationX: typing.Optional[int] = 0, LocationY: typing.Optional[int] = 0, SourceActions: typing.Optional[int] = 0, SupportedDataFlavors: typing.Optional[typing.Tuple[DataFlavor_ffd30deb, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Dummy (int, optional): Dummy value.
            Context (XDropTargetDragContext, optional): Context value.
            DropAction (int, optional): DropAction value.
            LocationX (int, optional): LocationX value.
            LocationY (int, optional): LocationY value.
            SourceActions (int, optional): SourceActions value.
            SupportedDataFlavors (typing.Tuple[DataFlavor, ...], optional): SupportedDataFlavors value.
        """

        if isinstance(Source, DropTargetDragEnterEvent):
            oth: DropTargetDragEnterEvent = Source
            self.Source = oth.Source
            self.Dummy = oth.Dummy
            self.Context = oth.Context
            self.DropAction = oth.DropAction
            self.LocationX = oth.LocationX
            self.LocationY = oth.LocationY
            self.SourceActions = oth.SourceActions
            self.SupportedDataFlavors = oth.SupportedDataFlavors
            return

        kargs = {
            "Source": Source,
            "Dummy": Dummy,
            "Context": Context,
            "DropAction": DropAction,
            "LocationX": LocationX,
            "LocationY": LocationY,
            "SourceActions": SourceActions,
            "SupportedDataFlavors": SupportedDataFlavors,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._supported_data_flavors = kwargs["SupportedDataFlavors"]
        inst_keys = ('SupportedDataFlavors',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def SupportedDataFlavors(self) -> typing.Tuple[DataFlavor_ffd30deb, ...]:
        """
        A sequence of supported com.sun.star.datatransfer.DataFlavor types.
        """
        return self._supported_data_flavors

    @SupportedDataFlavors.setter
    def SupportedDataFlavors(self, value: typing.Tuple[DataFlavor_ffd30deb, ...]) -> None:
        self._supported_data_flavors = value


__all__ = ['DropTargetDragEnterEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XMasterPasswordHandling(XInterface_8f010a43):
    """
    allows to change the master password, or let it be requested and checked.

    See Also:
        `API XMasterPasswordHandling <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XMasterPasswordHandling.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.XMasterPasswordHandling'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.task.XMasterPasswordHandling'

    @abstractmethod
    def allowPersistentStoring(self, bAllow: bool) -> bool:
        """
        allows to specify whether persistent storing of passwords is allowed
        
        After the storing is forbidden the master password and all the stored passwords are removed.
        """
        ...
    @abstractmethod
    def authorizateWithMasterPassword(self, xHandler: XInteractionHandler_bf80e51) -> bool:
        """
        allows to check the user authorization.
        
        This call let the master password be requested from user using the provided interaction handler.
        
        The call will use the standard interaction handler service InteractionHandler if no handler is provided.
        """
        ...
    @abstractmethod
    def changeMasterPassword(self, xHandler: XInteractionHandler_bf80e51) -> bool:
        """
        allows to change the master password.
        
        If there is still no master password, the user will be asked to provide the new one.
        
        The call will use the standard interaction handler service InteractionHandler if no handler is provided.
        """
        ...
    @abstractmethod
    def hasMasterPassword(self) -> bool:
        """
        allows to detect whether there is already a master password
        """
        ...
    @abstractmethod
    def isPersistentStoringAllowed(self) -> bool:
        """
        allows to detect whether persistent storing of passwords is allowed
        """
        ...
    @abstractmethod
    def removeMasterPassword(self) -> None:
        """
        let the master password and all the related stored passwords be removed.
        """
        ...

__all__ = ['XMasterPasswordHandling']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XRestartManager(XInterface_8f010a43):
    """
    allows to try to restart the office.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XRestartManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XRestartManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.XRestartManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.task.XRestartManager'

    @abstractmethod
    def isRestartRequested(self, bInitialized: bool) -> bool:
        """
        allows to get info whether the restart has been requested and provide the initialization status.
        
        The office has to call this method just before the main loop has been started, with the TRUE as argument, so that the implementation knows that the office is initialized. If the method returns TRUE, the office should restart without starting the main loop.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def requestRestart(self, xInteractionHandler: XInteractionHandler_bf80e51) -> None:
        """
        let the office restart asynchronously

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XRestartManager']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_engine_listener import XEngineListener as XEngineListener_f0b70d91
    from .x_library_access import XLibraryAccess as XLibraryAccess_e32a0d1c

class XEngine(XInterface_8f010a43):
    """
    makes it possible to control a scripting engine.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XEngine <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XEngine.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XEngine'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XEngine'

    @abstractmethod
    def addEngineListener(self, Listener: XEngineListener_f0b70d91) -> None:
        """
        adds an engine listener.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def cancel(self) -> None:
        """
        terminates the execution of the running script.
        
        The waiting queue is cleared too.
        """
        ...
    @abstractmethod
    def compile(self, ModuleName: str, Script: str, CreateDebugInfo: bool) -> bool:
        """
        compiles a script module in the scope of the root object.
        """
        ...
    @abstractmethod
    def getRoot(self) -> XInterface_8f010a43:
        """
        gets an interface to the object which is the scripting root.
        """
        ...
    @abstractmethod
    def removeEngineListener(self, Listener: XEngineListener_f0b70d91) -> None:
        """
        removes an engine listener.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def run(self, aScript: str, xThis: XInterface_8f010a43, aArgs: typing.Tuple[object, ...]) -> object:
        """
        runs a script specified by a string.
        
        The arguments given in aArgs can be ignored by the engine. The Script is executed synchronously.
        """
        ...
    @abstractmethod
    def runAsync(self, acript: str, xThis: XInterface_8f010a43, args: typing.Tuple[object, ...], xCallback: XEngineListener_f0b70d91) -> None:
        """
        runs the script specified by a string and makes callbacks.
        
        The arguments given in aArgs can be ignored by the engine. The script is executed asynchronously.
        """
        ...
    @abstractmethod
    def setLibraryAccess(self, Library: XLibraryAccess_e32a0d1c) -> None:
        """
        sets an access object to get external functions.
        """
        ...
    @abstractmethod
    def setRoot(self, xRoot: XInterface_8f010a43) -> None:
        """
        sets an interface to an object as a scripting root.
        
        If the root object implements the XInvocation interface, then the engine uses this interface to set/get properties and call methods.
        """
        ...

__all__ = ['XEngine']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class XAreaLinks(XIndexAccess_f0910d6d):
    """
    provides access via index to a collection of area links and inserting and removing area links.

    See Also:
        `API XAreaLinks <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XAreaLinks.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XAreaLinks'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XAreaLinks'

    @abstractmethod
    def insertAtPosition(self, aDestPos: CellAddress_ae5f0b56, aFileName: str, aSourceArea: str, aFilter: str, aFilterOptions: str) -> None:
        """
        creates an area link and adds it to the collection.
        
        This can be the address of a cell or range in the form \"Sheet1.A1:C5\", or the name of a named range or database range.
        """
        ...
    @abstractmethod
    def removeByIndex(self, nIndex: int) -> None:
        """
        removes an area link from the collection.
        """
        ...

__all__ = ['XAreaLinks']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.resource
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_string_resource_manager import XStringResourceManager as XStringResourceManager_80421142
if typing.TYPE_CHECKING:
    from ..embed.x_storage import XStorage as XStorage_8e460a32
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XStringResourcePersistence(XStringResourceManager_80421142):
    """
    Interface derived from XStringResourceManager containing basic persistence functionality limited to operations that are independent from an associated location or storage.

    See Also:
        `API XStringResourcePersistence <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourcePersistence.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.resource'
    __ooo_full_ns__: str = 'com.sun.star.resource.XStringResourcePersistence'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.resource.XStringResourcePersistence'

    @abstractmethod
    def exportBinary(self) -> uno.ByteSequence:
        """
        Returns a sequence of byte representing the complete string resource in a binary format.
        
        This method is intended to support datatransfer functionality, e.g. provided by com.sun.star.datatransfer.XTransferable and related interfaces.
        
        See importBinary()).
        """
        ...
    @abstractmethod
    def importBinary(self, Data: uno.ByteSequence) -> None:
        """
        Initializes the string resource with binary data.
        
        This method expects the data format returned by exportBinary().
        
        All locales and strings previously added to the string resource will be deleted. So after calling this method the string resource only contains the locales and strings specified in the binary data.
        
        This method is intended to support datatransfer functionality, e.g. provided by com.sun.star.datatransfer.XTransferable and related interfaces.
        
        See importBinary()).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def isModified(self) -> bool:
        """
        provides the current modify state of the StringResourceManager instance.
        """
        ...
    @abstractmethod
    def setComment(self, Comment: str) -> None:
        """
        Sets the comment stored first in each locale data file.
        
        This interface method can be used to overwrite the comment used during initialization of the services StringResourceWithLocation or StringResourceWithStorage
        """
        ...
    @abstractmethod
    def store(self) -> None:
        """
        Stores all string table data respectively all data modified since the last call to store() to the location or storage associated with the StringResourceManager.
        
        Each locale is stored in a single file following the format of Java properties files.
        
        This interface is supported by the services StringResourceWithLocation and StringResourceWithStorage
        
        The StringResourceWithLocation is initialized with a URL specifying a location used to load data from and store data to, see StringResourceWithLocation.
        
        The StringResourceWithStorage is initialized with an instance of com.sun.star.embed.XStorage used to load data from and store data to, see StringResourceWithStorage.
        
        If the string table isn't modified (see isModified()) this method does nothing.
        
        This method can throw all exceptions thrown by the methods of com.sun.star.embed.XStorage respectively a com.sun.star.ucb.CommandAbortedException in case of a StringResourceWithLocation for all exceptions that are not handled by a previously specified com.sun.star.task.XInteractionHandler. The handler to be used for the store operation can be specified during initialization of StringResourceWithLocation.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def storeToStorage(self, Storage: XStorage_8e460a32, BaseName: str, Comment: str) -> None:
        """
        Stores all string table data to the provided storage.
        
        Calling this method does not affect the association with a location (in case of a StringResourceWithLocation instance) respectively with a storage (in case of a StringResourceWithStorage instance). The modified state isn't affected either.
        
        This method can be used to make a copy of the current string table data to a storage. This method can throw all exceptions thrown by the methods of com.sun.star.embed.XStorage
        
        This method can throw all exceptions thrown by the methods of com.sun.star.embed.XStorage

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def storeToURL(self, URL: str, BaseName: str, Comment: str, Handler: XInteractionHandler_bf80e51) -> None:
        """
        Stores all string table data to the location specified by the passed URL string.
        
        Calling this method does not affect the association with a location (in case of a StringResourceWithLocation instance) respectively with a storage (in case of a StringResourceWithStorage instance). The modified state isn't affected either.
        
        This method can be used to make a copy of the current string table data to a location.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XStringResourcePersistence']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
from __future__ import annotations
from abc import abstractproperty
from .x_animate import XAnimate as XAnimate_ca680c52

class XAnimateTransform(XAnimate_ca680c52):
    """
    animates a transformation attribute on a target element, thereby allowing animations to control translation, scaling, rotation and/or skewing.
    
    The member XAnimate.Attributes contains a short from AnimationTransformType.
    
    Depending on the value in XAnimate.Attributes, the members XAnimate.From, XAnimate.To, XAnimate.By or XAnimate.Values contain the following

    See Also:
        `API XAnimateTransform <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimateTransform.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.XAnimateTransform'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.animations.XAnimateTransform'

    @abstractproperty
    def TransformType(self) -> int:
        """
        """
        ...


__all__ = ['XAnimateTransform']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .lock_entry import LockEntry as LockEntry_839e09dd
from .lock_scope import LockScope as LockScope_839109c5
from .lock_type import LockType as LockType_7a09096d
import typing
from .lock_depth import LockDepth as LockDepth_835c09c0


class Lock(LockEntry_839e09dd):
    """
    Struct Class

    defines a lock.

    See Also:
        `API Lock <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1Lock.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.Lock'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.Lock'
    """Literal Constant ``com.sun.star.ucb.Lock``"""

    def __init__(self, Scope: typing.Optional[LockScope_839109c5] = LockScope_839109c5.EXCLUSIVE, Type: typing.Optional[LockType_7a09096d] = LockType_7a09096d.WRITE, LockTokens: typing.Optional[typing.Tuple[str, ...]] = (), Depth: typing.Optional[LockDepth_835c09c0] = LockDepth_835c09c0.ZERO, Owner: typing.Optional[object] = None, Timeout: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Scope (LockScope, optional): Scope value.
            Type (LockType, optional): Type value.
            LockTokens (typing.Tuple[str, ...], optional): LockTokens value.
            Depth (LockDepth, optional): Depth value.
            Owner (object, optional): Owner value.
            Timeout (int, optional): Timeout value.
        """

        if isinstance(Scope, Lock):
            oth: Lock = Scope
            self.Scope = oth.Scope
            self.Type = oth.Type
            self.LockTokens = oth.LockTokens
            self.Depth = oth.Depth
            self.Owner = oth.Owner
            self.Timeout = oth.Timeout
            return

        kargs = {
            "Scope": Scope,
            "Type": Type,
            "LockTokens": LockTokens,
            "Depth": Depth,
            "Owner": Owner,
            "Timeout": Timeout,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._lock_tokens = kwargs["LockTokens"]
        self._depth = kwargs["Depth"]
        self._owner = kwargs["Owner"]
        self._timeout = kwargs["Timeout"]
        inst_keys = ('LockTokens', 'Depth', 'Owner', 'Timeout')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def LockTokens(self) -> typing.Tuple[str, ...]:
        """
        the lock tokens.
        
        Each lock token is a URI.
        """
        return self._lock_tokens

    @LockTokens.setter
    def LockTokens(self, value: typing.Tuple[str, ...]) -> None:
        self._lock_tokens = value

    @property
    def Depth(self) -> LockDepth_835c09c0:
        """
        defines the lock's depth.
        """
        return self._depth

    @Depth.setter
    def Depth(self, value: LockDepth_835c09c0) -> None:
        self._depth = value

    @property
    def Owner(self) -> object:
        """
        the owner of the lock.
        
        This element provides information sufficient for either directly contacting a principal (such as a telephone number or email URI), or for discovering the principal (such as the URL of a homepage) who owns the lock.
        """
        return self._owner

    @Owner.setter
    def Owner(self, value: object) -> None:
        self._owner = value

    @property
    def Timeout(self) -> int:
        """
        a timeout value for the lock.
        
        This element specifies the number of seconds between granting of the lock and the automatic removal of that lock. The value must not be greater than 2^32-1. A value of -1 stands for an infinite lock, that will never be removed automatically.
        """
        return self._timeout

    @Timeout.setter
    def Timeout(self, value: int) -> None:
        self._timeout = value


__all__ = ['Lock']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tab
from __future__ import annotations
from abc import abstractproperty
from .x_tab_page_model import XTabPageModel as XTabPageModel_dcde0c96

class UnoControlTabPageModel(XTabPageModel_dcde0c96):
    """
    Service Class

    specifies the standard model of a XTabPageModel.
    
    **since**
    
        OOo 3.4

    See Also:
        `API UnoControlTabPageModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1tab_1_1UnoControlTabPageModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tab'
    __ooo_full_ns__: str = 'com.sun.star.awt.tab.UnoControlTabPageModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HScroll(self) -> bool:
        """
        specifies that a horizontal scrollbar should be added to the dialog
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the dialog.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the dialog.
        """
        ...

    @abstractproperty
    def ScrollHeight(self) -> int:
        """
        specifies the total height of the scrollable dialog content
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def ScrollLeft(self) -> int:
        """
        specifies the horizontal position of the scrolled dialog content
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def ScrollTop(self) -> int:
        """
        specifies the vertical position of the scrolled dialog content
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def ScrollWidth(self) -> int:
        """
        specifies the total width of the scrollable dialog content
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        specifies the text that is displayed in the caption bar of the dialog.
        """
        ...

    @abstractproperty
    def VScroll(self) -> bool:
        """
        specifies that a vertical scrollbar should be added to the dialog
        
        **since**
        
            LibreOffice 7.1
        """
        ...


__all__ = ['UnoControlTabPageModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tab
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .x_tab_page import XTabPage as XTabPage_a2060aa5
    from .x_tab_page_container_listener import XTabPageContainerListener as XTabPageContainerListener_940d118e

class XTabPageContainer(ABC):
    """
    An interface to a control that displays tab pages.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XTabPageContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tab'
    __ooo_full_ns__: str = 'com.sun.star.awt.tab.XTabPageContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.tab.XTabPageContainer'

    @abstractmethod
    def addTabPageContainerListener(self, listener: XTabPageContainerListener_940d118e) -> None:
        """
        Adds a listener for the TabPageActivedEvent posted after the tab page was activated.
        """
        ...
    @abstractmethod
    def getTabPage(self, tabPageIndex: int) -> XTabPage_a2060aa5:
        """
        Returns tab page for the given index.
        """
        ...
    @abstractmethod
    def getTabPageByID(self, tabPageID: int) -> XTabPage_a2060aa5:
        """
        Returns tab page for the given ID.
        """
        ...
    @abstractmethod
    def getTabPageCount(self) -> int:
        """
        Returns the number of tab pages.
        """
        ...
    @abstractmethod
    def isTabPageActive(self, tabPageIndex: int) -> bool:
        """
        Checks whether a tab page is activated.
        """
        ...
    @abstractmethod
    def removeTabPageContainerListener(self, listener: XTabPageContainerListener_940d118e) -> None:
        """
        Removes a listener previously added with addTabPageListener().
        """
        ...
    @abstractproperty
    def ActiveTabPageID(self) -> int:
        """
        Specifies the ID of the current active tab page.
        """
        ...


__all__ = ['XTabPageContainer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.packages
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XDataSinkEncrSupport(XInterface_8f010a43):
    """
    Allows to get access to the stream of a PackageStream.

    See Also:
        `API XDataSinkEncrSupport <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1packages_1_1XDataSinkEncrSupport.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.packages'
    __ooo_full_ns__: str = 'com.sun.star.packages.XDataSinkEncrSupport'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.packages.XDataSinkEncrSupport'

    @abstractmethod
    def getDataStream(self) -> XInputStream_98d40ab4:
        """
        Allows to get access to the data of the PackageStream.
        
        In case stream is encrypted one and the key for the stream is not set, an exception must be thrown.

        Raises:
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.packages.zip.ZipException: ``ZipException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def getPlainRawStream(self) -> XInputStream_98d40ab4:
        """
        Allows to get access to the raw data of the stream as it is stored in the package.

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
        """
        ...
    @abstractmethod
    def getRawStream(self) -> XInputStream_98d40ab4:
        """
        Allows to get access to the data of the PackageStream as to raw stream.
        
        In case stream is not encrypted an exception will be thrown.
        
        The difference of raw stream is that it contains header for encrypted data, so an encrypted stream can be copied from one PackageStream to another one without decryption.

        Raises:
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def setDataStream(self, aStream: XInputStream_98d40ab4) -> None:
        """
        Allows to set a data stream for the PackageStream.
        
        In case PackageStream is marked as encrypted the data stream will be encrypted on storing.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def setRawStream(self, aStream: XInputStream_98d40ab4) -> None:
        """
        Allows to set raw stream for the PackageStream.
        
        The PackageStream object can not be marked as encrypted one, an exception will be thrown in such case.

        Raises:
            com.sun.star.packages.EncryptionNotAllowedException: ``EncryptionNotAllowedException``
            com.sun.star.packages.NoRawFormatException: ``NoRawFormatException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XDataSinkEncrSupport']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.deployment
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
if typing.TYPE_CHECKING:
    from ..beans.string_pair import StringPair as StringPair_a4bc0b14
    from .x_package_type_info import XPackageTypeInfo as XPackageTypeInfo_3bc70f7b
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..task.x_abort_channel import XAbortChannel as XAbortChannel_baca0bc4
    from ..ucb.x_command_environment import XCommandEnvironment as XCommandEnvironment_fb330dee

class XPackage(XComponent_98dc0ab5, XModifyBroadcaster_fd990df0):
    """
    Objects of this interface reflect a bound package and are issued by a PackageRegistryBackend.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPackage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.deployment'
    __ooo_full_ns__: str = 'com.sun.star.deployment.XPackage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.deployment.XPackage'

    @abstractmethod
    def checkDependencies(self, xCmdEnv: XCommandEnvironment_fb330dee) -> bool:
        """
        checks if the dependencies for this package are still satisfied
        
        After updating the OpenOffice.org, some dependencies for packages might no longer be satisfied.
        
        **since**
        
            OOo 3.2

        Raises:
            DeploymentException: ``DeploymentException``
            ExtensionRemovedException: ``ExtensionRemovedException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
        """
        ...
    @abstractmethod
    def checkPrerequisites(self, xAbortChannel: XAbortChannel_baca0bc4, xCmdEnv: XCommandEnvironment_fb330dee, alreadyInstalled: bool) -> int:
        """
        checks if the package can be installed.
        
        Only if the return value is TRUE the package is allowed to be installed. In case of FALSE or in case of an exception, the package must be removed completely. After return of this function no code from the extension may be used anymore, so that the extension can be safely removed from the hard disk.

        Raises:
            DeploymentException: ``DeploymentException``
            ExtensionRemovedException: ``ExtensionRemovedException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
        """
        ...
    @abstractmethod
    def createAbortChannel(self) -> XAbortChannel_baca0bc4:
        """
        creates a command channel to be used to asynchronously abort a command.
        """
        ...
    @abstractmethod
    def exportTo(self, destFolderURL: str, newTitle: str, nameClashAction: int, xCmdEnv: XCommandEnvironment_fb330dee) -> None:
        """
        exports package to given destination URL.

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.ucb.ContentCreationException: ``ContentCreationException``
        """
        ...
    @abstractmethod
    def getBundle(self, xAbortChannel: XAbortChannel_baca0bc4, xCmdEnv: XCommandEnvironment_fb330dee) -> typing.Tuple[XPackage, ...]:
        """
        Gets packages of the bundle.
        
        If isRemoved() returns TRUE then getBundle may return an empty sequence in case the object is not registered.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getDescription(self) -> str:
        """
        returns a description string to describe the package.

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getDisplayName(self) -> str:
        """
        returns the display name of the package, e.g.
        
        for graphical user interfaces (GUI).

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getIcon(self, highContrast: bool) -> XGraphic_a4da0afc:
        """
        returns an icon for a package.

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getIdentifier(self) -> object:
        """
        returns the unique extension identifier.
        """
        ...
    @abstractmethod
    def getLicenseText(self) -> str:
        """
        returns a string containing the license text.

        Raises:
            DeploymentException: ``DeploymentException``
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        returns the file name of the package.
        """
        ...
    @abstractmethod
    def getPackageType(self) -> XPackageTypeInfo_3bc70f7b:
        """
        returns the XPackageTypeInfo, e.g.
        
        media-type etc.
        """
        ...
    @abstractmethod
    def getPublisherInfo(self) -> StringPair_a4bc0b14:
        """
        returns the publisher info for the package, the strings might be empty, if there is no publisher
        
        com.sun.star.beans.StringPair.First represents the publisher name and com.sun.star.beans.StringPair.Second represents the URL to the publisher.

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getRegistrationDataURL(self) -> object:
        """
        return a URL to a directory which contains the registration data.
        
        This data may be created when calling XPackage.registerPackage(). If this is the case is indicated by com.sun.star.beans.Optional.IsPresent of the return value. If registration data are created during registration, but the package is currently not registered, for example after calling XPackage.revokePackage(), then com.sun.star.beans.Optional.IsPresent is TRUE and the com.sun.star.beans.Optional.Value may be an empty string.

        Raises:
            DeploymentException: ``DeploymentException``
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getRepositoryName(self) -> str:
        """
        returns the name of the repository where this object comes from.
        """
        ...
    @abstractmethod
    def getURL(self) -> str:
        """
        returns the location of the package.
        """
        ...
    @abstractmethod
    def getUpdateInformationURLs(self) -> typing.Tuple[str, ...]:
        """
        returns a sequence of update information URLs.
        
        The sequence may be empty in case no update information is available. If the sequence contains more than one URL, the extra URLs must mirror the information available at the first URL.

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def getVersion(self) -> str:
        """
        returns the textual version representation of the package.
        
        A textual version representation is a finite string following the BNFversion .= [element (\".\" element)*]element .= (\"0\" | \"1\" | \"2\" | \"3\" | \"4\" | \"5\" | \"6\" | \"7\" | \"8\" | \"9\")+

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
        ...
    @abstractmethod
    def isBundle(self) -> bool:
        """
        reflects whether this package is a bundle of one or more packages, e.g.
        
        a zip (legacy) package file or a document hosting script packages.
        """
        ...
    @abstractmethod
    def isRegistered(self, xAbortChannel: XAbortChannel_baca0bc4, xCmdEnv: XCommandEnvironment_fb330dee) -> object:
        """
        determines whether the package is currently registered, i.e.
        
        whether it is active.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
        """
        ...
    @abstractmethod
    def isRemoved(self) -> bool:
        """
        indicates if this object represents a removed extension or extension item.
        
        This is the case when it was created by providing TRUE for the removed parameter in the function XPackageRegistry.bindPackage().
        """
        ...
    @abstractmethod
    def registerPackage(self, startup: bool, xAbortChannel: XAbortChannel_baca0bc4, xCmdEnv: XCommandEnvironment_fb330dee) -> None:
        """
        registers this XPackage.
        
        NEVER call this directly. This is done by the extension manager if necessary.

        Raises:
            DeploymentException: ``DeploymentException``
            ExtensionRemovedException: ``ExtensionRemovedException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def revokePackage(self, startup: bool, xAbortChannel: XAbortChannel_baca0bc4, xCmdEnv: XCommandEnvironment_fb330dee) -> None:
        """
        revokes this XPackage.
        
        NEVER call this directly. This is done by the extension manager if necessary.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XPackage']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class reservedWords(object):
    """
    Const Class

    Offsets into the sequence of strings returned by XLocaleData.getReservedWord().

    See Also:
        `API reservedWords <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1reservedWords.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.reservedWords'
    __ooo_type_name__: str = 'const'

    TRUE_WORD = 0
    """
    \"true\"
    """
    FALSE_WORD = 1
    """
    \"false\"
    """
    QUARTER1_WORD = 2
    """
    \"1st quarter\"
    """
    QUARTER2_WORD = 3
    """
    \"2nd quarter\"
    """
    QUARTER3_WORD = 4
    """
    \"3rd quarter\"
    """
    QUARTER4_WORD = 5
    """
    \"4th quarter\"
    """
    ABOVE_WORD = 6
    """
    \"above\"
    """
    BELOW_WORD = 7
    """
    \"below\"
    """
    QUARTER1_ABBREVIATION = 8
    """
    \"Q1\"
    """
    QUARTER2_ABBREVIATION = 9
    """
    \"Q2\"
    """
    QUARTER3_ABBREVIATION = 10
    """
    \"Q3\"
    """
    QUARTER4_ABBREVIATION = 11
    """
    \"Q4\"
    """
    COUNT = 12
    """
    Yes, this must be the count of known reserved words and one more than the maximum number used above! Count of known reserved words.
    """

__all__ = ['reservedWords']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.scanner
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_scanner_manager import XScannerManager as XScannerManager_fd640dcf
if typing.TYPE_CHECKING:
    from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a

class XScannerManager2(XScannerManager_fd640dcf):
    """
    Extension of XScannerManager.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API XScannerManager2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1scanner_1_1XScannerManager2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.scanner'
    __ooo_full_ns__: str = 'com.sun.star.scanner.XScannerManager2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.scanner.XScannerManager2'

    @abstractmethod
    def configureScannerAndScan(self, scannerContext: object, listener: XEventListener_c7230c4a) -> bool:
        """
        produce some kind of User Interface to let the user have a preview, configure the scan area, etc., it, and scan it returns FALSE if user cancelled this process

        Raises:
            com.sun.star.scanner.ScannerException: ``ScannerException``
        """
        ...

__all__ = ['XScannerManager2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_text_range import XTextRange as XTextRange_9a910ab7

class XTextContent(XComponent_98dc0ab5):
    """
    enables objects to be inserted into a text and to provide their location in a text once they are inserted into it.

    See Also:
        `API XTextContent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextContent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XTextContent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XTextContent'

    @abstractmethod
    def attach(self, xTextRange: XTextRange_9a910ab7) -> None:
        """
        is called when this object gets embedded in a text.
        
        This acts like a multi-phase construction, thus the object may be invalid until it is attached to a text position. Usually this method is called from within XText.insertTextContent().
        
        Both text objects and text content objects may only be connected to each other if they are created by the same component. When implementing new components, this behavior is deprecated.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getAnchor(self) -> XTextRange_9a910ab7:
        """
        Note: The anchor of the actual implementation for text tables does not have a position in the text. Thus that anchor can not be used for some operation like attach() for example or com.sun.star.text.insertTextContent or other function that require the object to have a position in the text.
        
        The reason why a text table still needs an anchor is that for example tables should be insertable via com.sun.star.text.insertTextContent and that interface uses a parameter of that type.
        """
        ...

__all__ = ['XTextContent']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans


class PropertyConcept(object):
    """
    Const Class

    These constants are used to specify concepts of the introspection which apply to properties and to the methods which represent attributes.
    
    This list is not necessarily complete; new constants may be added.

    See Also:
        `API PropertyConcept <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans_1_1PropertyConcept.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertyConcept'
    __ooo_type_name__: str = 'const'

    ALL = -1
    """
    This value is used to query for all properties.
    
    See XIntrospectionAccess.getProperty() and XIntrospectionAccess.getProperties()
    """
    DANGEROUS = 1
    """
    specifies that the change or retrieval of this property directly by the user can result in an unstable state (deadlock, application crash, security hole, etc.)
    """
    PROPERTYSET = 2
    """
    specifies all properties which are reachable by XPropertySet, XFastPropertySet or XMultiPropertySet.
    """
    ATTRIBUTES = 4
    """
    specifies all properties which are actually attributes of interfaces.
    """
    METHODS = 8
    """
    specifies all properties which are represented by getter or setter methods.
    
    These methods have the signature type get...(), void set...() or boolean is...().
    """

__all__ = ['PropertyConcept']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_container_listener import XContainerListener as XContainerListener_4b89100c

class XContainer(XInterface_8f010a43):
    """
    supports quick access to the information if a container currently contains elements.
    
    The XContainer interface is provided for containers which need to broadcast changes within the container; that means the actions of adding or removing elements are broadcast to the listeners.
    
    This can be useful for UI to enable/disable some functions without actually accessing the data.

    See Also:
        `API XContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.XContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.container.XContainer'

    @abstractmethod
    def addContainerListener(self, xListener: XContainerListener_4b89100c) -> None:
        """
        adds the specified listener to receive events when elements are inserted or removed.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def removeContainerListener(self, xListener: XContainerListener_4b89100c) -> None:
        """
        removes the specified listener so it does not receive any events from this container.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...

__all__ = ['XContainer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.sdbc.batch_update_exception import BatchUpdateException as BatchUpdateException
from ...lo.sdbc.best_row_scope import BestRowScope as BestRowScope
from ...lo.sdbc.best_row_type import BestRowType as BestRowType
from ...lo.sdbc.callable_statement import CallableStatement as CallableStatement
from ...lo.sdbc.change_action import ChangeAction as ChangeAction
from ...lo.sdbc.change_event import ChangeEvent as ChangeEvent
from ...lo.sdbc.column_search import ColumnSearch as ColumnSearch
from ...lo.sdbc.column_type import ColumnType as ColumnType
from ...lo.sdbc.column_value import ColumnValue as ColumnValue
from ...lo.sdbc.connection import Connection as Connection
from ...lo.sdbc.connection_pool import ConnectionPool as ConnectionPool
from ...lo.sdbc.connection_properties import ConnectionProperties as ConnectionProperties
from ...lo.sdbc.dbase_connection_properties import DBASEConnectionProperties as DBASEConnectionProperties
from ...lo.sdbc.data_truncation import DataTruncation as DataTruncation
from ...lo.sdbc.data_type import DataType as DataType
from ...lo.sdbc.deferrability import Deferrability as Deferrability
from ...lo.sdbc.driver import Driver as Driver
from ...lo.sdbc.driver_manager import DriverManager as DriverManager
from ...lo.sdbc.driver_property_info import DriverPropertyInfo as DriverPropertyInfo
from ...lo.sdbc.file_connection_properties import FILEConnectionProperties as FILEConnectionProperties
from ...lo.sdbc.flat_connection_properties import FLATConnectionProperties as FLATConnectionProperties
from ...lo.sdbc.fetch_direction import FetchDirection as FetchDirection
from ...lo.sdbc.index_type import IndexType as IndexType
from ...lo.sdbc.jdbc_connection_properties import JDBCConnectionProperties as JDBCConnectionProperties
from ...lo.sdbc.key_rule import KeyRule as KeyRule
from ...lo.sdbc.odbc_connection_properties import ODBCConnectionProperties as ODBCConnectionProperties
from ...lo.sdbc.prepared_statement import PreparedStatement as PreparedStatement
from ...lo.sdbc.procedure_column import ProcedureColumn as ProcedureColumn
from ...lo.sdbc.procedure_result import ProcedureResult as ProcedureResult
from ...lo.sdbc.result_set import ResultSet as ResultSet
from ...lo.sdbc.result_set_concurrency import ResultSetConcurrency as ResultSetConcurrency
from ...lo.sdbc.result_set_type import ResultSetType as ResultSetType
from ...lo.sdbc.row_set import RowSet as RowSet
from ...lo.sdbc.sql_exception import SQLException as SQLException
from ...lo.sdbc.sql_warning import SQLWarning as SQLWarning
from ...lo.sdbc.statement import Statement as Statement
from ...lo.sdbc.transaction_isolation import TransactionIsolation as TransactionIsolation
from ...lo.sdbc.x_array import XArray as XArray
from ...lo.sdbc.x_batch_execution import XBatchExecution as XBatchExecution
from ...lo.sdbc.x_blob import XBlob as XBlob
from ...lo.sdbc.x_clob import XClob as XClob
from ...lo.sdbc.x_closeable import XCloseable as XCloseable
from ...lo.sdbc.x_column_locate import XColumnLocate as XColumnLocate
from ...lo.sdbc.x_connection import XConnection as XConnection
from ...lo.sdbc.x_connection_pool import XConnectionPool as XConnectionPool
from ...lo.sdbc.x_data_source import XDataSource as XDataSource
from ...lo.sdbc.x_database_meta_data import XDatabaseMetaData as XDatabaseMetaData
from ...lo.sdbc.x_database_meta_data2 import XDatabaseMetaData2 as XDatabaseMetaData2
from ...lo.sdbc.x_driver import XDriver as XDriver
from ...lo.sdbc.x_driver_access import XDriverAccess as XDriverAccess
from ...lo.sdbc.x_driver_manager import XDriverManager as XDriverManager
from ...lo.sdbc.x_driver_manager2 import XDriverManager2 as XDriverManager2
from ...lo.sdbc.x_generated_result_set import XGeneratedResultSet as XGeneratedResultSet
from ...lo.sdbc.x_isolated_connection import XIsolatedConnection as XIsolatedConnection
from ...lo.sdbc.x_multiple_results import XMultipleResults as XMultipleResults
from ...lo.sdbc.x_out_parameters import XOutParameters as XOutParameters
from ...lo.sdbc.x_parameters import XParameters as XParameters
from ...lo.sdbc.x_pooled_connection import XPooledConnection as XPooledConnection
from ...lo.sdbc.x_prepared_batch_execution import XPreparedBatchExecution as XPreparedBatchExecution
from ...lo.sdbc.x_prepared_statement import XPreparedStatement as XPreparedStatement
from ...lo.sdbc.x_ref import XRef as XRef
from ...lo.sdbc.x_result_set import XResultSet as XResultSet
from ...lo.sdbc.x_result_set_meta_data import XResultSetMetaData as XResultSetMetaData
from ...lo.sdbc.x_result_set_meta_data_supplier import XResultSetMetaDataSupplier as XResultSetMetaDataSupplier
from ...lo.sdbc.x_result_set_update import XResultSetUpdate as XResultSetUpdate
from ...lo.sdbc.x_row import XRow as XRow
from ...lo.sdbc.x_row_set import XRowSet as XRowSet
from ...lo.sdbc.x_row_set_listener import XRowSetListener as XRowSetListener
from ...lo.sdbc.x_row_update import XRowUpdate as XRowUpdate
from ...lo.sdbc.xsql_data import XSQLData as XSQLData
from ...lo.sdbc.xsql_input import XSQLInput as XSQLInput
from ...lo.sdbc.xsql_output import XSQLOutput as XSQLOutput
from ...lo.sdbc.x_statement import XStatement as XStatement
from ...lo.sdbc.x_struct import XStruct as XStruct
from ...lo.sdbc.x_warnings_supplier import XWarningsSupplier as XWarningsSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs


class ControlActions(object):
    """
    Const Class

    Control actions for common and extended controls of a FilePicker.

    See Also:
        `API ControlActions <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ControlActions.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.ControlActions'
    __ooo_type_name__: str = 'const'

    ADD_ITEM = 1
    """
    Adds an item to the content of the listbox.
    
    The given item has to be a string.
    """
    ADD_ITEMS = 2
    """
    Adds a sequence of strings to the content of the listbox.
    """
    DELETE_ITEM = 3
    """
    Removes an item from a listbox.
    
    The given value has to be a position. If the position is invalid an exception will be thrown. The index of the first position is 0. The value should be a sal_Int32.
    """
    DELETE_ITEMS = 4
    """
    Removes all items from the listbox.
    """
    SET_SELECT_ITEM = 5
    """
    Selects an item in a listbox.
    
    The given value has to be a position. The index of the first position is 0. A value of -1 removes the selection. If the given position is invalid an exception will be thrown. The value should be a sal_Int32.
    """
    GET_ITEMS = 6
    """
    Returns all items of the listbox as a sequence of strings.
    """
    GET_SELECTED_ITEM = 7
    """
    Returns the currently selected item.
    
    The returned item is an empty string if the listbox is empty or no item is selected.
    """
    GET_SELECTED_ITEM_INDEX = 8
    """
    Returns the zero based index of the currently selected item.
    
    If the listbox is empty or there is no item selected -1 will be returned. The returned value is a sal_Int32.
    """
    SET_HELP_URL = 100
    """
    Sets the help URL of a control.
    """
    GET_HELP_URL = 101
    """
    Retrieves the help URL of a control.
    """

__all__ = ['ControlActions']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from ..container.x_container_query import XContainerQuery as XContainerQuery_1cdd0edc
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from ..util.x_flushable import XFlushable as XFlushable_9a420ab4

class FilterFactory(XContainerQuery_1cdd0edc, XNameContainer_cb90e47, XMultiServiceFactory_191e0eb6, XFlushable_9a420ab4):
    """
    Service Class

    factory to create filter components.
    
    After a generic TypeDetection an internal type name will be known. Further a generic com.sun.star.frame.FrameLoader can use this information, to search a suitable filter (may the default filter) at this factory and use it for loading the document into a specified frame.
    
    This factory implements read/write access on the underlying configuration set. and further a validate and flush mechanism for more performance and a special query mode can be used here too.

    See Also:
        `API FilterFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1FilterFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.FilterFactory'
    __ooo_type_name__: str = 'service'


__all__ = ['FilterFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility


class AccessibleTableModelChangeType(object):
    """
    Const Class

    Type of a change made to a table model.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleTableModelChangeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1accessibility_1_1AccessibleTableModelChangeType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.AccessibleTableModelChangeType'
    __ooo_type_name__: str = 'const'

    UPDATE = 3
    """
    Some of the table data has changed.
    
    The number of rows and columns remains unchanged. Only (some of) the content of the cells in the range that is specified by the fields of the AccessibleTableModelChange structure have been changed.
    """
    ROWS_INSERTED = 4
    """
    One or more rows have been inserted.
    
    Use the fields of the AccessibleTableModelChange structure to determine the indices of the rows that have been inserted. Column indices should be set to -1.
    
    **since**
    
        LibreOffice 7.4
    """
    COLUMNS_INSERTED = 5
    """
    One or more columns have been inserted.
    
    Use the fields of the AccessibleTableModelChange structure to determine the indices of the columns that have been inserted. Row indices should be set to -1.
    
    **since**
    
        LibreOffice 7.4
    """
    ROWS_REMOVED = 6
    """
    One or more rows have been removed.
    
    Use the fields of the AccessibleTableModelChange structure to determine the indices of the rows that have been removed. Column indices should be set to -1.
    
    **since**
    
        LibreOffice 7.4
    """
    COLUMNS_REMOVED = 7
    """
    One or more columns have been removed.
    
    Use the fields of the AccessibleTableModelChange structure to determine the indices of the columns that have been removed. Row indices should be set to -1.
    
    **since**
    
        LibreOffice 7.4
    """

__all__ = ['AccessibleTableModelChangeType']
